diff --git a/src/backend/access/hash/hashovfl.c b/src/backend/access/hash/hashovfl.c
index b512d0bcb6..7a4d28e8a6 100644
--- a/src/backend/access/hash/hashovfl.c
+++ b/src/backend/access/hash/hashovfl.c
@@ -647,6 +647,7 @@ _hash_freeovflpage(Relation rel, Buffer bucketbuf, Buffer ovflbuf,
 		xl_hash_squeeze_page xlrec;
 		XLogRecPtr	recptr;
 		int			i;
+		bool		wbuf_registered = false;
 
 		xlrec.prevblkno = prevblkno;
 		xlrec.nextblkno = nextblkno;
@@ -671,6 +672,10 @@ _hash_freeovflpage(Relation rel, Buffer bucketbuf, Buffer ovflbuf,
 		if (xlrec.ntups > 0)
 		{
 			XLogRegisterBuffer(1, wbuf, REGBUF_STANDARD);
+
+			/* Track the registration status for later use */
+			wbuf_registered = true;
+
 			XLogRegisterBufData(1, (char *) itup_offsets,
 								nitups * sizeof(OffsetNumber));
 			for (i = 0; i < nitups; i++)
@@ -692,6 +697,9 @@ _hash_freeovflpage(Relation rel, Buffer bucketbuf, Buffer ovflbuf,
 			if (!xlrec.is_prev_bucket_same_wrt)
 				wbuf_flags |= REGBUF_NO_CHANGE;
 			XLogRegisterBuffer(1, wbuf, wbuf_flags);
+
+			/* Track the registration status for later use */
+			wbuf_registered = true;
 		}
 
 		XLogRegisterBuffer(2, ovflbuf, REGBUF_STANDARD);
@@ -719,7 +727,12 @@ _hash_freeovflpage(Relation rel, Buffer bucketbuf, Buffer ovflbuf,
 
 		recptr = XLogInsert(RM_HASH_ID, XLOG_HASH_SQUEEZE_PAGE);
 
-		PageSetLSN(BufferGetPage(wbuf), recptr);
+		/* Set LSN to wbuf page buffer only when it is being registered */
+		if (wbuf_registered)
+			PageSetLSN(BufferGetPage(wbuf), recptr);
+		else
+			elog(LOG, "XXX: is_wbuf_registered: %s", wbuf_registered ? "true" : "false");
+
 		PageSetLSN(BufferGetPage(ovflbuf), recptr);
 
 		if (BufferIsValid(prevbuf) && !xlrec.is_prev_bucket_same_wrt)
